/*
    The following code replicates the estimates and figures in the paper, 
	"Electoral and Policy Consequences of Voter Turnout: Evidence from Compulsory Voting in Australia."
	Feel free to contact the author, Anthony Fowler (fowler@fas.harvard.edu), with comments or questions.
	
	Before running the code, be sure that you have installed the "synth" package by running the following 3 lines:
	net from http://www.mit.edu/~jhainm/Synth
	net describe synth
	net install synth, all replace force 
	More information on this package is available at http://www.mit.edu/~jhainm/synthpage.html.
 */

************** Bendigo Analysis **************
clear
set more off
use "Bendigo.dta"
*average difference between owners and non-owners
reg voted owner, r
g logvalue = ln(value)
sum logvalue
g logvalue_recode = (logvalue - r(mean))/r(sd)
*relationship between property value and voting for owners
reg voted logvalue_recode if owner == 1, r
*relationship between property value and voting for non-owners
reg voted logvalue_recode if owner == 0, r
*Figure 1
lpoly voted logvalue if owner == 1, gen(kernel_owners) at(logvalue) bw(1.5) se(se_owners) nograph 
lpoly voted logvalue if owner == 0, gen(kernel_occupiers) at(logvalue) bw(1.5) se(se_occupiers) nograph
g upper_owners = kernel_owners + se_owners
g lower_owners = kernel_owners - se_owners
g upper_occupiers = kernel_occupiers + se_occupiers
g lower_occupiers = kernel_occupiers - se_occupiers
sort logvalue
graph twoway line kernel_owners kernel_occupiers upper* lower* logvalue
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush ln(Property Value)
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .xaxis1.reset_rule 1 7 2 , tickset(major) ruletype(range) 
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.title.text.Arrpush Pr(Turnout in Special Election)
gr_edit .style.editstyle margin(vsmall) editcopy
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .plotregion1.plot1.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot1.style.editstyle line(width(thick)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(width(thick)) editcopy
gr_edit .plotregion1.plot6.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot6.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot4.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot4.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.plot5.style.editstyle line(color(black)) editcopy
gr_edit .plotregion1.plot5.style.editstyle line(pattern(dot)) editcopy
gr_edit .plotregion1.AddTextBox added_text editor .6766377654794543 1.314498412584046
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(small) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush Owners
gr_edit .plotregion1.AddTextBox added_text editor .5315819588040339 2.709040887063172
gr_edit .plotregion1.added_text_new = 2
gr_edit .plotregion1.added_text_rec = 2
gr_edit .plotregion1.added_text[2].style.editstyle  angle(default) size(small) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[2].text = {}
gr_edit .plotregion1.added_text[2].text.Arrpush Occupiers
graph save "Figure1.gph", replace


************** Analysis of State Assembly Elections **************
clear
set more off
set matsize 5000
use "StateAssemblyData.dta"
sum year
g time = (year - r(min))/(r(max) - r(min))
forvalues i = 1/6 {
g state`i' = statecode == `i'
g trend`i' = time*state`i'
}
g time2 = time^2
g time3 = time^3
g cutpoint = 1928 if statecode == 1
replace cutpoint = 1941 if statecode == 2
replace cutpoint = 1912 if statecode == 3
replace cutpoint = 1927 if statecode == 4
replace cutpoint = 1924 if statecode == 5
replace cutpoint = 1936 if statecode == 6
g years_after = year - cutpoint
g yr_after = years_after * compulsory
g yr_before = years_after * (1 - compulsory)
g turnout_before = turnout if compulsory == 0
g turnout_after = turnout if compulsory == 1
g voteshare_before = voteshare if compulsory == 0
g voteshare_after = voteshare if compulsory == 1

*Figure 2A
graph twoway scatter turnout_before turnout_after year, by(state)
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .b1title.text = {}
gr_edit .b1title.text.Arrpush Year
gr_edit .note.draw_view.setstyle, style(no)
gr_edit .style.editstyle margin(vsmall) editcopy
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
gr_edit .plotregion1.subtitle[4].style.editstyle fillcolor(white) editcopy
gr_edit .plotregion1.subtitle[4].style.editstyle linestyle(color(white)) editcopy
gr_edit .plotregion1.yaxis1[1].reset_rule .5 1 .1 , tickset(major) ruletype(range) 
gr_edit .plotregion1.yaxis1[4].reset_rule .5 1 .1 , tickset(major) ruletype(range) 
gr_edit .plotregion1.yaxis1[1].title.fill_if_undrawn.setstyle, style(no)
gr_edit .plotregion1.yaxis1[1].style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .plotregion1.xaxis1[4].style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
gr_edit .plotregion1.plotregion1[1].plot2.style.editstyle marker(size(medlarge)) editcopy
gr_edit .plotregion1.plotregion1[1].plot2.style.editstyle marker(symbol(triangle)) editcopy
gr_edit .plotregion1.plotregion1[1].plot2.style.editstyle marker(fillcolor(black)) editcopy
gr_edit .plotregion1.plotregion1[1].plot2.style.editstyle marker(linestyle(color(black))) editcopy
gr_edit .plotregion1.plotregion1[1].plot1.style.editstyle marker(size(medlarge)) editcopy
gr_edit .plotregion1.plotregion1[1].plot1.style.editstyle marker(symbol(triangle_hollow)) editcopy
gr_edit .plotregion1.plotregion1[1].plot1.style.editstyle marker(fillcolor(black)) editcopy
gr_edit .plotregion1.plotregion1[1].plot1.style.editstyle marker(linestyle(color(black))) editcopy
gr_edit .l1title.text = {}
gr_edit .l1title.text.Arrpush Voter Turnout
graph save "Figure2A.gph", replace
*Figure 2B
graph twoway scatter voteshare_before voteshare_after year, by(state)
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .b1title.text = {}
gr_edit .b1title.text.Arrpush Year
gr_edit .note.draw_view.setstyle, style(no)
gr_edit .style.editstyle margin(vsmall) editcopy
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
gr_edit .plotregion1.subtitle[4].style.editstyle fillcolor(white) editcopy
gr_edit .plotregion1.subtitle[4].style.editstyle linestyle(color(white)) editcopy
gr_edit .plotregion1.yaxis1[1].reset_rule .2 .6 .1 , tickset(major) ruletype(range) 
gr_edit .plotregion1.yaxis1[4].reset_rule .2 .6 .1 , tickset(major) ruletype(range) 
gr_edit .plotregion1.yaxis1[1].title.fill_if_undrawn.setstyle, style(no)
gr_edit .plotregion1.yaxis1[1].style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .plotregion1.xaxis1[4].style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
gr_edit .plotregion1.plotregion1[1].plot2.style.editstyle marker(size(medlarge)) editcopy
gr_edit .plotregion1.plotregion1[1].plot2.style.editstyle marker(symbol(triangle)) editcopy
gr_edit .plotregion1.plotregion1[1].plot2.style.editstyle marker(fillcolor(black)) editcopy
gr_edit .plotregion1.plotregion1[1].plot2.style.editstyle marker(linestyle(color(black))) editcopy
gr_edit .plotregion1.plotregion1[1].plot1.style.editstyle marker(size(medlarge)) editcopy
gr_edit .plotregion1.plotregion1[1].plot1.style.editstyle marker(symbol(triangle_hollow)) editcopy
gr_edit .plotregion1.plotregion1[1].plot1.style.editstyle marker(fillcolor(black)) editcopy
gr_edit .plotregion1.plotregion1[1].plot1.style.editstyle marker(linestyle(color(black))) editcopy
gr_edit .l1title.text = {}
gr_edit .l1title.text.Arrpush Labor Vote Share
graph save "Figure2B.gph", replace

*Table 2
xi:areg turnout compulsory i.statecode, a(year) cluster(statecode)
xi:areg turnout compulsory i.statecode trend* time, a(year) cluster(statecode)
xi:areg voteshare compulsory i.statecode, a(year) cluster(statecode)
xi:areg voteshare compulsory i.statecode trend* time, a(year) cluster(statecode)
xi:areg seatshare compulsory i.statecode, a(year) cluster(statecode)
xi:areg seatshare compulsory i.statecode trend* time, a(year) cluster(statecode)
	
*Table A2
xi:areg voteshare compulsory i.statecode, a(year) cluster(statecode)
xi:areg voteshare compulsory i.statecode trend* time, a(year) cluster(statecode)
xi:reg voteshare compulsory i.statecode time, cluster(statecode)
xi:reg voteshare compulsory i.statecode time time2, cluster(statecode)
xi:reg voteshare compulsory i.statecode time time2 time3, cluster(statecode)
xi:reg voteshare compulsory i.statecode yr_before yr_after, cluster(statecode)

*Table A1
*Traditional Standard Errors
xi:areg voteshare compulsory i.statecode, a(year) 
*Huber-White Het-Robust
xi:areg voteshare compulsory i.statecode, a(year) r
*State-clustered
xi:areg voteshare compulsory i.statecode, a(year) cluster(statecode)
*Nonparametric Bootstrap (increase the number of bootstrap samples for more precision)
xi: bootstrap, reps(1000): areg voteshare compulsory i.statecode, a(year)
*Block Bootstrap (again, up the sample size for more precision)
matrix B = J(1000,1,.)
forvalues i = 1/1000 {
quietly{
preserve
bsample, cluster(statecode) 
xi:areg voteshare compulsory i.state, a(year)
matrix B[`i',1] = _b[compulsory]
restore
}
}
svmat B
sum B
drop B*
*Random Permutations (use 100,000 instead of 1,000 to replicate Figure A1) 
quietly{
matrix B = J(1000, 1, .)
forvalues i = 1/1000{
scalar threshold1 = uniform()*40 + 1910
scalar threshold2 = uniform()*40 + 1910
scalar threshold3 = uniform()*40 + 1910
scalar threshold4 = uniform()*40 + 1910
scalar threshold5 = uniform()*40 + 1910
scalar threshold6 = uniform()*40 + 1910
g comp_rand = 0
replace comp_rand = 1 if year > threshold1 & statecode == 1
replace comp_rand = 1 if year > threshold2 & statecode == 2
replace comp_rand = 1 if year > threshold3 & statecode == 3
replace comp_rand = 1 if year > threshold4 & statecode == 4
replace comp_rand = 1 if year > threshold5 & statecode == 5
replace comp_rand = 1 if year > threshold6 & statecode == 6
xi:reg voteshare comp_rand i.year i.statecode
matrix B`j'[`i',1] = _b[comp_rand]
drop comp_rand
}
}
svmat B
sum B
*Figure A1
hist B, normal
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Random Permutation Results
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .xaxis1.reset_rule -.2 .2 .1 , tickset(major) ruletype(range) 
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.title.text.Arrpush Density
gr_edit .style.editstyle margin(vsmall) editcopy
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .plotregion1.AddTextBox added_text editor 8 .092
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(small) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1]._set_orientation vertical
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush Esimated Effect of Compulsory Voting on Labor Vote
gr_edit .plotregion1.plot1.style.editstyle area(shadestyle(color(blue))) editcopy
gr_edit .plotregion1.plot1.style.editstyle area(linestyle(color(navy))) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(color(gs7)) editcopy
graph save "FigureA1.gph", replace


************** Tests for Confounding Demographic Trends **************
clear
set more off
use "StateCensusData.dta"
g log_pop = log(male_pop + female_pop)
g prop_under21 = (popunder21/(male_pop+female_pop))
g prop_married = (married/(male_pop+female_pop))
g prop_borninaus = (borninaustralia/(male_pop+female_pop))
g prop_coe = (churchofengland/(male_pop+female_pop))
g prop_manufacturing = (manufacturing/(male_pop+female_pop))
g statecode = 1 if state == "NSW"
replace statecode = 2 if state == "VIC"
replace statecode = 3 if state == "QNZ"
replace statecode = 4 if state == "SA"
replace statecode = 5 if state == "WA"
replace statecode = 6 if state == "TAS"
*Table 3
xi:reg log_pop compulsory i.statecode i.year, cluster(statecode)
xi:reg prop_under21 compulsory i.statecode i.year, cluster(statecode)
xi:reg prop_married compulsory i.statecode i.year, cluster(statecode)
xi:reg prop_borninaus compulsory i.statecode i.year, cluster(statecode)
xi:reg prop_coe compulsory i.statecode i.year, cluster(statecode)
xi:reg prop_manufacturing compulsory i.statecode i.year, cluster(statecode)


************** Cross-Country Synthetic Control Analysis **************
*Turnout Analysis
clear
set more off
use "LindertData.dta"
replace turnout = .65325 if country_code == 1 & year == 1910
replace turnout = .6975 if country_code == 1 & year == 1920
replace turnout = .94018 if country_code == 1 & year == 1930
sort country_code year
g lag_pension = pension[_n-1]
replace lag_pension = . if country_code[_n-1] != country_code
replace lag_pension = . if year  == 1910
g delta_pension = pension - lag_pension
sort country_code year
g lag_turnout = turnout[_n-1]
replace lag_turnout = . if country_code[_n-1] != country_code
replace lag_turnout = . if year == 1910
g delta_turnout = turnout - lag_turnout
egen min_turnout = min(turnout), by(country_code)
drop if min_turnout == 0
egen country_code2 = group(country_code)
tsset country_code2 year
synth turnout delta_turnout turnout, trp(1930) tru(1) fig
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Year
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.title.text.Arrpush Voter Turnout
gr_edit .style.editstyle margin(vsmall) editcopy
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .plotregion1._xylines[1].style.editstyle linestyle(pattern(tight_dot)) editcopy
gr_edit .plotregion1._xylines[1].z = 1924
gr_edit .plotregion1.AddTextBox added_text editor .71 1924.877087294574
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(small) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1].style.editstyle size(medsmall) editcopy
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush Synthetic Control
gr_edit .plotregion1.AddTextBox added_text editor .89 1924.571752107504
gr_edit .plotregion1.added_text_new = 2
gr_edit .plotregion1.added_text_rec = 2
gr_edit .plotregion1.added_text[2].style.editstyle  angle(default) size(small) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[2].style.editstyle size(medsmall) editcopy
gr_edit .plotregion1.added_text[2].text = {}
gr_edit .plotregion1.added_text[2].text.Arrpush Australia
gr_edit .plotregion1.added_text[2].DragBy -.0012760705945455 .4143834681653527
gr_edit .plotregion1.plot1.style.editstyle line(width(thick)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(width(thick)) editcopy
gr_edit .xaxis1.reset_rule 1910 1930 10 , tickset(major) ruletype(range) 
gr_edit .xaxis1.plotregion.xscale.curmax = 1931
gr_edit .plotregion1.AddMarker added_markers editor 1910 .65324998
gr_edit .plotregion1.added_markers_new = 1
gr_edit .plotregion1.added_markers_rec = 1
gr_edit .plotregion1.added_markers[1].style.editstyle  marker( symbol(diamond) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(large) angle(stdarrow) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(zero) backangle(stdarrow)) line( width(thin) color(black) pattern(solid)) area( linestyle( width(thin) color(ltbluishgray) pattern(solid)) shadestyle( color(ltbluishgray) intensity(inten100) fill(pattern10))) label( textstyle( horizontal(center) vertical(middle) angle(default) size(small) color(black) position() margin(zero) linestyle( width(thin) color(black) pattern(solid))) position(6) textgap(half_tiny) horizontal(default) vertical(default)) dots( symbol(circle) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(vtiny) angle(horizontal) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(medium) backangle(horizontal)) connect(direct) connect_missings(yes) editcopy
gr_edit .plotregion1.AddMarker added_markers editor 1920 .6974999
gr_edit .plotregion1.added_markers_new = 2
gr_edit .plotregion1.added_markers_rec = 2
gr_edit .plotregion1.added_markers[2].style.editstyle  marker( symbol(diamond) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(large) angle(stdarrow) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(zero) backangle(stdarrow)) line( width(thin) color(black) pattern(solid)) area( linestyle( width(thin) color(ltbluishgray) pattern(solid)) shadestyle( color(ltbluishgray) intensity(inten100) fill(pattern10))) label( textstyle( horizontal(center) vertical(middle) angle(default) size(small) color(black) position() margin(zero) linestyle( width(thin) color(black) pattern(solid))) position(6) textgap(half_tiny) horizontal(default) vertical(default)) dots( symbol(circle) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(vtiny) angle(horizontal) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(medium) backangle(horizontal)) connect(direct) connect_missings(yes) editcopy
gr_edit .plotregion1.AddMarker added_markers editor 1930 .94018
gr_edit .plotregion1.added_markers_new = 3
gr_edit .plotregion1.added_markers_rec = 3
gr_edit .plotregion1.added_markers[3].style.editstyle  marker( symbol(diamond) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(large) angle(stdarrow) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(zero) backangle(stdarrow)) line( width(thin) color(black) pattern(solid)) area( linestyle( width(thin) color(ltbluishgray) pattern(solid)) shadestyle( color(ltbluishgray) intensity(inten100) fill(pattern10))) label( textstyle( horizontal(center) vertical(middle) angle(default) size(small) color(black) position() margin(zero) linestyle( width(thin) color(black) pattern(solid))) position(6) textgap(half_tiny) horizontal(default) vertical(default)) dots( symbol(circle) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(vtiny) angle(horizontal) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(medium) backangle(horizontal)) connect(direct) connect_missings(yes) editcopy
gr_edit .plotregion1.AddMarker added_markers editor 1930 .75362101
gr_edit .plotregion1.added_markers_new = 4
gr_edit .plotregion1.added_markers_rec = 4
gr_edit .plotregion1.added_markers[4].style.editstyle  marker( symbol(diamond) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(large) angle(stdarrow) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(zero) backangle(stdarrow)) line( width(thin) color(black) pattern(solid)) area( linestyle( width(thin) color(ltbluishgray) pattern(solid)) shadestyle( color(ltbluishgray) intensity(inten100) fill(pattern10))) label( textstyle( horizontal(center) vertical(middle) angle(default) size(small) color(black) position() margin(zero) linestyle( width(thin) color(black) pattern(solid))) position(6) textgap(half_tiny) horizontal(default) vertical(default)) dots( symbol(circle) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(vtiny) angle(horizontal) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(medium) backangle(horizontal)) connect(direct) connect_missings(yes) editcopy
gr_edit .plotregion1.AddTextBox added_text editor .9 1923.6
gr_edit .plotregion1.added_text_new = 3
gr_edit .plotregion1.added_text_rec = 3
gr_edit .plotregion1.added_text[3].style.editstyle  angle(default) size(small) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[3].style.editstyle size(vsmall) editcopy
gr_edit .plotregion1.added_text[3]._set_orientation vertical
gr_edit .plotregion1.added_text[3].text = {}
gr_edit .plotregion1.added_text[3].text.Arrpush 1924: Compulsory Voting Implemented
graph save "Figure3A.gph", replace
matrix TREATED = e(Y_treated)
matrix CONTROL = e(Y_synthetic)
scalar treated_before = TREATED[2, 1]
scalar treated_after = TREATED[3, 1]
scalar control_before = CONTROL[2, 1]
scalar control_after = CONTROL[3, 1]
disp (treated_after - treated_before) - (control_after - control_before)
*Placebos
drop if country_code == 1
matrix B = J(11, 2, .)
forvalues i = 2/11{
qui:synth turnout delta_turnout turnout, trp(1930) tru(`i')
matrix TREATED = e(Y_treated)
matrix CONTROL = e(Y_synthetic)
scalar treated_before = TREATED[2, 1]
scalar treated_after = TREATED[3, 1]
scalar control_before = CONTROL[2, 1]
scalar control_after = CONTROL[3, 1]
matrix B[`i', 1] = `i'
matrix B[`i', 2] = (treated_after - treated_before) - (control_after - control_before)
}
matrix list B

*Pension Analysis
clear
set more off
use "LindertData.dta"
replace turnout = .65325 if country_code == 1 & year == 1910
replace turnout = .6975 if country_code == 1 & year == 1920
replace turnout = .94018 if country_code == 1 & year == 1930
sort country_code year
g lag_pension = pension[_n-1]
replace lag_pension = . if country_code[_n-1] != country_code
replace lag_pension = . if year  == 1910
g delta_pension = pension - lag_pension
sort country_code year
g lag_turnout = turnout[_n-1]
replace lag_turnout = . if country_code[_n-1] != country_code
replace lag_turnout = . if year == 1910
g delta_turnout = turnout - lag_turnout
tsset country_code year
*Figure 3B
synth pension delta_pension pension, trp(1930) tru(1) fig
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Year
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.title.text.Arrpush Pension Spending (% of GDP)
gr_edit .style.editstyle margin(vsmall) editcopy
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .plotregion1._xylines[1].style.editstyle linestyle(pattern(tight_dot)) editcopy
gr_edit .plotregion1._xylines[1].z = 1924
gr_edit .plotregion1.AddTextBox added_text editor .8847335225065911 1924.877087294574
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(small) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1].style.editstyle size(medsmall) editcopy
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush Synthetic Control
gr_edit .plotregion1.AddTextBox added_text editor 1.284143618599375 1924.571752107504
gr_edit .plotregion1.added_text_new = 2
gr_edit .plotregion1.added_text_rec = 2
gr_edit .plotregion1.added_text[2].style.editstyle  angle(default) size(small) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[2].style.editstyle size(medsmall) editcopy
gr_edit .plotregion1.added_text[2].text = {}
gr_edit .plotregion1.added_text[2].text.Arrpush Australia
gr_edit .plotregion1.added_text[2].DragBy -.0012760705945455 .4143834681653527
gr_edit .plotregion1.plot1.style.editstyle line(width(thick)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(width(thick)) editcopy
gr_edit .xaxis1.reset_rule 1910 1930 10 , tickset(major) ruletype(range) 
gr_edit .xaxis1.plotregion.xscale.curmax = 1931
gr_edit .plotregion1.AddMarker added_markers editor 1910 .60000002
gr_edit .plotregion1.added_markers_new = 1
gr_edit .plotregion1.added_markers_rec = 1
gr_edit .plotregion1.added_markers[1].style.editstyle  marker( symbol(diamond) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(large) angle(stdarrow) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(zero) backangle(stdarrow)) line( width(thin) color(black) pattern(solid)) area( linestyle( width(thin) color(ltbluishgray) pattern(solid)) shadestyle( color(ltbluishgray) intensity(inten100) fill(pattern10))) label( textstyle( horizontal(center) vertical(middle) angle(default) size(small) color(black) position() margin(zero) linestyle( width(thin) color(black) pattern(solid))) position(6) textgap(half_tiny) horizontal(default) vertical(default)) dots( symbol(circle) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(vtiny) angle(horizontal) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(medium) backangle(horizontal)) connect(direct) connect_missings(yes) editcopy
gr_edit .plotregion1.AddMarker added_markers editor 1920 .81999999
gr_edit .plotregion1.added_markers_new = 2
gr_edit .plotregion1.added_markers_rec = 2
gr_edit .plotregion1.added_markers[2].style.editstyle  marker( symbol(diamond) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(large) angle(stdarrow) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(zero) backangle(stdarrow)) line( width(thin) color(black) pattern(solid)) area( linestyle( width(thin) color(ltbluishgray) pattern(solid)) shadestyle( color(ltbluishgray) intensity(inten100) fill(pattern10))) label( textstyle( horizontal(center) vertical(middle) angle(default) size(small) color(black) position() margin(zero) linestyle( width(thin) color(black) pattern(solid))) position(6) textgap(half_tiny) horizontal(default) vertical(default)) dots( symbol(circle) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(vtiny) angle(horizontal) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(medium) backangle(horizontal)) connect(direct) connect_missings(yes) editcopy
gr_edit .plotregion1.AddMarker added_markers editor 1930 1.41
gr_edit .plotregion1.added_markers_new = 3
gr_edit .plotregion1.added_markers_rec = 3
gr_edit .plotregion1.added_markers[3].style.editstyle  marker( symbol(diamond) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(large) angle(stdarrow) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(zero) backangle(stdarrow)) line( width(thin) color(black) pattern(solid)) area( linestyle( width(thin) color(ltbluishgray) pattern(solid)) shadestyle( color(ltbluishgray) intensity(inten100) fill(pattern10))) label( textstyle( horizontal(center) vertical(middle) angle(default) size(small) color(black) position() margin(zero) linestyle( width(thin) color(black) pattern(solid))) position(6) textgap(half_tiny) horizontal(default) vertical(default)) dots( symbol(circle) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(vtiny) angle(horizontal) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(medium) backangle(horizontal)) connect(direct) connect_missings(yes) editcopy
gr_edit .plotregion1.AddMarker added_markers editor 1930 .99635002
gr_edit .plotregion1.added_markers_new = 4
gr_edit .plotregion1.added_markers_rec = 4
gr_edit .plotregion1.added_markers[4].style.editstyle  marker( symbol(diamond) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(large) angle(stdarrow) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(zero) backangle(stdarrow)) line( width(thin) color(black) pattern(solid)) area( linestyle( width(thin) color(ltbluishgray) pattern(solid)) shadestyle( color(ltbluishgray) intensity(inten100) fill(pattern10))) label( textstyle( horizontal(center) vertical(middle) angle(default) size(small) color(black) position() margin(zero) linestyle( width(thin) color(black) pattern(solid))) position(6) textgap(half_tiny) horizontal(default) vertical(default)) dots( symbol(circle) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(vtiny) angle(horizontal) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(medium) backangle(horizontal)) connect(direct) connect_missings(yes) editcopy
gr_edit .plotregion1.AddTextBox added_text editor 1.25 1923.6
gr_edit .plotregion1.added_text_new = 3
gr_edit .plotregion1.added_text_rec = 3
gr_edit .plotregion1.added_text[3].style.editstyle  angle(default) size(small) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[3].style.editstyle size(vsmall) editcopy
gr_edit .plotregion1.added_text[3]._set_orientation vertical
gr_edit .plotregion1.added_text[3].text = {}
gr_edit .plotregion1.added_text[3].text.Arrpush 1924: Compulsory Voting Implemented
graph save "Figure3B.gph", replace
matrix TREATED = e(Y_treated)
matrix CONTROL = e(Y_synthetic)
scalar treated_before = TREATED[2, 1]
scalar treated_after = TREATED[3, 1]
scalar control_before = CONTROL[2, 1]
scalar control_after = CONTROL[3, 1]
disp (treated_after - treated_before) - (control_after - control_before)
*Placebos
drop if country_code == 1
matrix B = J(21, 2, .)
forvalues i = 2/21{
qui:synth pension delta_pension  pension, trp(1930) tru(`i')
matrix TREATED = e(Y_treated)
matrix CONTROL = e(Y_synthetic)
scalar treated_before = TREATED[2, 1]
scalar treated_after = TREATED[3, 1]
scalar control_before = CONTROL[2, 1]
scalar control_after = CONTROL[3, 1]
matrix B[`i', 1] = `i'
matrix B[`i', 2] = (treated_after - treated_before) - (control_after - control_before)
}
matrix list B

